@@ -28,8 +28,11 @@ class _ws(suds.client.Client):
 
 class ContentService(_ws):
 	"CDS ContentService Client"
-	def __init__(self, service=None, faults=True):
-		self.SERVICEADDRESS = "https://%s/cds-controller/contentService?wsdl" % (CDSDOMAIN, )
+	def __init__(self, service=None, faults=True, _https=True):
+		if _https:
+			self.SERVICEADDRESS = "https://%s/cds-controller/contentService?wsdl" % (CDSDOMAIN, )
+		else:
+			self.SERVICEADDRESS = "http://%s/cds-controller/contentService?wsdl" % (CDSDOMAIN, )
 		_ws.__init__(
 			self,
 			service=service,
@@ -40,8 +43,11 @@ class ContentService(_ws):
 
 class MediaItemService(_ws):
 	"CDS ContentService Client"
-	def __init__(self, service=None, faults=True):
-		self.SERVICEADDRESS = "https://%s/mediaitemmanager/manage?wsdl" % (CDSDOMAIN, )
+	def __init__(self, service=None, faults=True, _https=True):
+		if _https:
+			self.SERVICEADDRESS = "https://%s/mediaitemmanager/manage?wsdl" % (CDSDOMAIN, )
+		else:
+			self.SERVICEADDRESS = "http://%s/mediaitemmanager/manage?wsdl" % (CDSDOMAIN, )
 		_ws.__init__(
 			self,
 			service=service,
